==> istio-model-v1alpha3-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl<A extends EnvoyFilterEnvoyConfigObjectMatchClusterFluent<A>> extends BaseFluent<A> implements EnvoyFilterEnvoyConfigObjectMatchClusterFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl() {
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl(EnvoyFilterEnvoyConfigObjectMatchCluster instance) {
    this.withCluster(instance.getCluster()); 
  }
  private EnvoyFilterClusterMatchBuilder cluster;
  
  /**
   * This method has been deprecated, please use method buildCluster instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterClusterMatch getCluster() {
    return this.cluster!=null ?this.cluster.build():null;
  }
  public EnvoyFilterClusterMatch buildCluster() {
    return this.cluster!=null ?this.cluster.build():null;
  }
  public A withCluster(EnvoyFilterClusterMatch cluster) {
    _visitables.get("cluster").remove(this.cluster);
    if (cluster!=null){ this.cluster= new EnvoyFilterClusterMatchBuilder(cluster); _visitables.get("cluster").add(this.cluster);} else { this.cluster = null; _visitables.get("cluster").remove(this.cluster); } return (A) this;
  }
  public Boolean hasCluster() {
    return this.cluster != null;
  }
  public A withNewCluster(String name,Integer portNumber,String service,String subset) {
    return (A)withCluster(new EnvoyFilterClusterMatch(name, portNumber, service, subset));
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluent.ClusterNested<A> withNewCluster() {
    return new EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNestedImpl();
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluent.ClusterNested<A> withNewClusterLike(EnvoyFilterClusterMatch item) {
    return new EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNestedImpl(item);
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluent.ClusterNested<A> editCluster() {
    return withNewClusterLike(getCluster());
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluent.ClusterNested<A> editOrNewCluster() {
    return withNewClusterLike(getCluster() != null ? getCluster(): new EnvoyFilterClusterMatchBuilder().build());
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluent.ClusterNested<A> editOrNewClusterLike(EnvoyFilterClusterMatch item) {
    return withNewClusterLike(getCluster() != null ? getCluster(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl that = (EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl) o;
    if (cluster != null ? !cluster.equals(that.cluster) :that.cluster != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cluster,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cluster != null) { sb.append("cluster:"); sb.append(cluster); }
    sb.append("}");
    return sb.toString();
  }
  class ClusterNestedImpl<N> extends EnvoyFilterClusterMatchFluentImpl<EnvoyFilterEnvoyConfigObjectMatchClusterFluent.ClusterNested<N>> implements EnvoyFilterEnvoyConfigObjectMatchClusterFluent.ClusterNested<N>,Nested<N>{
    ClusterNestedImpl(EnvoyFilterClusterMatch item) {
      this.builder = new EnvoyFilterClusterMatchBuilder(this, item);
    }
    ClusterNestedImpl() {
      this.builder = new EnvoyFilterClusterMatchBuilder(this);
    }
    EnvoyFilterClusterMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.this.withCluster(builder.build());
    }
    public N endCluster() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl<A extends EnvoyFilterEnvoyConfigObjectMatchClusterFluent<A>> extends BaseFluent<A> implements EnvoyFilterEnvoyConfigObjectMatchClusterFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl() {
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl(EnvoyFilterEnvoyConfigObjectMatchCluster instance) {
    if (instance != null) {
      this.withCluster(instance.getCluster());
    }
  }
  private EnvoyFilterClusterMatchBuilder cluster;
  
  /**
   * This method has been deprecated, please use method buildCluster instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterClusterMatch getCluster() {
    return this.cluster!=null ?this.cluster.build():null;
  }
  public EnvoyFilterClusterMatch buildCluster() {
    return this.cluster!=null ?this.cluster.build():null;
  }
  public A withCluster(EnvoyFilterClusterMatch cluster) {
    _visitables.get("cluster").remove(this.cluster);
    if (cluster!=null){ this.cluster= new EnvoyFilterClusterMatchBuilder(cluster); _visitables.get("cluster").add(this.cluster);} else { this.cluster = null; _visitables.get("cluster").remove(this.cluster); } return (A) this;
  }
  public Boolean hasCluster() {
    return this.cluster != null;
  }
  public A withNewCluster(String name,Integer portNumber,String service,String subset) {
    return (A)withCluster(new EnvoyFilterClusterMatch(name, portNumber, service, subset));
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNested<A> withNewCluster() {
    return new EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNestedImpl();
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNested<A> withNewClusterLike(EnvoyFilterClusterMatch item) {
    return new EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNestedImpl(item);
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNested<A> editCluster() {
    return withNewClusterLike(getCluster());
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNested<A> editOrNewCluster() {
    return withNewClusterLike(getCluster() != null ? getCluster(): new EnvoyFilterClusterMatchBuilder().build());
  }
  public EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNested<A> editOrNewClusterLike(EnvoyFilterClusterMatch item) {
    return withNewClusterLike(getCluster() != null ? getCluster(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl that = (EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl) o;
    if (!java.util.Objects.equals(cluster, that.cluster)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cluster,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cluster != null) { sb.append("cluster:"); sb.append(cluster); }
    sb.append("}");
    return sb.toString();
  }
  class ClusterNestedImpl<N> extends EnvoyFilterClusterMatchFluentImpl<EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNested<N>> implements EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.ClusterNested<N>,Nested<N>{
    ClusterNestedImpl(EnvoyFilterClusterMatch item) {
      this.builder = new EnvoyFilterClusterMatchBuilder(this, item);
    }
    ClusterNestedImpl() {
      this.builder = new EnvoyFilterClusterMatchBuilder(this);
    }
    EnvoyFilterClusterMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchClusterFluentImpl.this.withCluster(builder.build());
    }
    public N endCluster() {
      return and();
    }
    
  }
  
}
